# Agena

Agena is a Gemini-to-Gopher proxy written in Python, released under the BSD
2-Clause License.  There is an
[Agena page in Geminispace](gemini://zaibatsu.circumlunar.space/~solderpunk/software/agena/),
which also has a
[webpage mirror](https://zaibatsu.circumlunar.space/~solderpunk/software/agena/).
You can access formatted versions of the Agena man page there, as well as other
useful information, release history, etc.

By design, Agena consists of a single file, `agena.py`, and has no mandatory
dependencies beyond the Python standard library (although the `chardet` library
will be used opportunistically if installed).  You can install it with `pip`,
or just copy `agena.py` to somewhere in your `$PATH`.

The source code lives in a
[git repo hosted at SourceHut](https://git.sr.ht/~solderpunk/agena).  There is
also [a ticket tracker](https://todo.sr.ht/~solderpunk/gemini-tools) you can
use to report bugs.

The git repository contains the following files (plus some development /
packaging related noise):

* LICENSE - text of BSD 2-Clause License
* README.md - the README file you are currently reading
* agena.1 - troff source for the agena(1) man page
* agena.py - Python source for Agena itself
